@@ -36,6 +36,51 @@ def get_host(key='foo'):
     return get_host
 
 
+# get_host
+parent_dir = os.path.dirname(os.path.abspath(__file__))
+build_dir = os.path.join(parent_dir, "./manage_settings/frontend/build")
+_manage_settings = _components.declare_component("manage_settings", path=build_dir)
+
+
+def manage_settings(key='foo', *, settings):
+    """Create a new instance of "get_host".
+
+    Parameters
+    ----------
+    key: str or None
+        An optional key that uniquely identifies this component. If this is
+        None, and the component's arguments are changed, the component will
+        be re-mounted in the Streamlit frontend and lose its current state.
+    settings: dict
+        A dictionary with the following structure
+        
+        {
+            "earth_anchor": {"lat": float, "lon": float},
+            "units": 'Meters' | 'Millimeters' | 'Feet' | 'Inches' | 'Centimeters',
+            "layers": string[],
+            "tolerance": float,
+            "angle_tolerance": float
+        }
+
+    Returns
+    -------
+    settings: 
+        A dictionary with the following structure
+
+        {
+            "earth_anchor": {"lat": float, "lon": float},
+            "units": integer,
+            "layers": string[],
+            "tolerance": float,
+            "angle_tolerance": float
+        }
+    """
+
+    manage_settings = _manage_settings(key=key, settings=settings)
+
+    return manage_settings
+
+
 # get_geometry
 parent_dir = os.path.dirname(os.path.abspath(__file__))
 build_dir = os.path.join(parent_dir, "./get_geometry/frontend/build")
@@ -786,3 +831,67 @@ def select_run(
         base_path=client["_host"])
 
     return select_run
+
+
+
+# select_run
+parent_dir = os.path.dirname(os.path.abspath(__file__))
+build_dir = os.path.join(parent_dir, "./create_study/frontend/build")
+_create_study = _components.declare_component(
+    "create_study", path=build_dir)
+
+
+def create_study(
+    key='foo', api_client: ApiClient = None, *,
+    on_change:  Callable = None,
+    args: Tuple = None,
+    kwargs: Dict = None
+):
+    """Create a new instance of "select_run".
+
+    Parameters
+    ----------
+    key: str or None
+        An optional key that uniquely identifies this component. If this is
+        None, and the component's arguments are changed, the component will
+        be re-mounted in the Streamlit frontend and lose its current state.
+    api_client: ApiClient
+        ApiClient is a class returned by get_api_client(), part of the 
+        pollination_streamlit package.
+        ```
+        from pollination_streamlit.selectors import get_api_client
+        ...
+        api_client = get_api_client
+        ```
+    on_change: Callable or None
+        An optional on_change function that will be called when hbjson input
+        is changed.
+    args: Tuple or None
+        An optional tuple of positional arguments that will be passed to the
+        on_change function.
+    kwargs: dictionary or None
+        An optional dictionary of kwargs that will be passed to the on_change
+        function.
+        
+    Returns
+    -------
+    dict
+        A dictionary with the sturcture described here:
+
+            https://api.pollination.cloud/docs#/Runs/list_runs
+    """
+
+    if on_change is not None:
+        args = args or []
+        kwargs = kwargs or {}
+        register_callback(key, on_change, *args, **kwargs)
+
+    client = api_client.__dict__
+
+    create_study = _create_study(
+        key=key,
+        access_token=client["_jwt_token"],
+        api_key=client["_api_token"],
+        base_path=client["_host"])
+
+    return create_study
